@@ -1,7 +1,8 @@
 package TestApp;
-use Mouse;
+use Moo;
+use MooX::Types::MooseLike::Base qw(HashRef);
 
-has context => ( is => 'ro', isa => 'HashRef', lazy => 1, default => sub { {} } );
+has context => ( is => 'ro', isa => HashRef, lazy => 1, default => sub { {} } );
 
 sub runme {
     my ( $self ) = @_;
@@ -11,6 +12,4 @@ sub runme {
     sleep $sleep;
 }
 
-no Mouse;
-
 1;
